@@ -1,7 +1,9 @@
+const semver = require('semver');
+
 /**
  * Module of mixed-in functions shared between node and client code
  */
-const isObject = require('./is-object');
+const { isObject, hasOwn } = require('./utils');
 
 /**
  * Expose `RequestBase`.
@@ -15,26 +17,7 @@ module.exports = RequestBase;
  * @api public
  */
 
-function RequestBase(object) {
-  if (object) return mixin(object);
-}
-
-/**
- * Mixin the prototype properties.
- *
- * @param {Object} obj
- * @return {Object}
- * @api private
- */
-
-function mixin(object) {
-  for (const key in RequestBase.prototype) {
-    if (Object.prototype.hasOwnProperty.call(RequestBase.prototype, key))
-      object[key] = RequestBase.prototype[key];
-  }
-
-  return object;
-}
+function RequestBase() {}
 
 /**
  * Clear previous timeout.
@@ -127,7 +110,7 @@ RequestBase.prototype.timeout = function (options) {
   }
 
   for (const option in options) {
-    if (Object.prototype.hasOwnProperty.call(options, option)) {
+    if (hasOwn(options, option)) {
       switch (option) {
         case 'deadline':
           this._timeout = options.deadline;
@@ -191,16 +174,7 @@ const ERROR_CODES = new Set([
 ]);
 
 const STATUS_CODES = new Set([
-  408,
-  413,
-  429,
-  500,
-  502,
-  503,
-  504,
-  521,
-  522,
-  524
+  408, 413, 429, 500, 502, 503, 504, 521, 522, 524
 ]);
 
 // TODO: we would need to make this easily configurable before adding it in (e.g. some might want to add POST)
@@ -214,19 +188,19 @@ const STATUS_CODES = new Set([
  * @param {Response} [res] response
  * @returns {Boolean} if segment should be retried
  */
-RequestBase.prototype._shouldRetry = function (err, res) {
+RequestBase.prototype._shouldRetry = function (error, res) {
   if (!this._maxRetries || this._retries++ >= this._maxRetries) {
     return false;
   }
 
   if (this._retryCallback) {
     try {
-      const override = this._retryCallback(err, res);
+      const override = this._retryCallback(error, res);
       if (override === true) return true;
       if (override === false) return false;
       // undefined falls back to defaults
-    } catch (err_) {
-      console.error(err_);
+    } catch (error_) {
+      console.error(error_);
     }
   }
 
@@ -240,11 +214,11 @@ RequestBase.prototype._shouldRetry = function (err, res) {
     return false;
   */
   if (res && res.status && STATUS_CODES.has(res.status)) return true;
-  if (err) {
-    if (err.code && ERROR_CODES.has(err.code)) return true;
+  if (error) {
+    if (error.code && ERROR_CODES.has(error.code)) return true;
     // Superagent timeout
-    if (err.timeout && err.code === 'ECONNABORTED') return true;
-    if (err.crossDomain) return true;
+    if (error.timeout && error.code === 'ECONNABORTED') return true;
+    if (error.crossDomain) return true;
   }
 
   return false;
@@ -301,15 +275,15 @@ RequestBase.prototype.then = function (resolve, reject) {
           return;
         }
 
-        const err = new Error('Aborted');
-        err.code = 'ABORTED';
-        err.status = this.status;
-        err.method = this.method;
-        err.url = this.url;
-        reject(err);
+        const error = new Error('Aborted');
+        error.code = 'ABORTED';
+        error.status = this.status;
+        error.method = this.method;
+        error.url = this.url;
+        reject(error);
       });
-      self.end((err, res) => {
-        if (err) reject(err);
+      self.end((error, res) => {
+        if (error) reject(error);
         else resolve(res);
       });
     });
@@ -400,8 +374,7 @@ RequestBase.prototype.getHeader = RequestBase.prototype.get;
 RequestBase.prototype.set = function (field, value) {
   if (isObject(field)) {
     for (const key in field) {
-      if (Object.prototype.hasOwnProperty.call(field, key))
-        this.set(key, field[key]);
+      if (hasOwn(field, key)) this.set(key, field[key]);
     }
 
     return this;
@@ -446,10 +419,11 @@ RequestBase.prototype.unset = function (field) {
  *
  * @param {String|Object} name name of field
  * @param {String|Blob|File|Buffer|fs.ReadStream} val value of field
+ * @param {String} options extra options, e.g. 'blob'
  * @return {Request} for chaining
  * @api public
  */
-RequestBase.prototype.field = function (name, value) {
+RequestBase.prototype.field = function (name, value, options) {
   // name should be either a string or an object.
   if (name === null || undefined === name) {
     throw new Error('.field(name, val) name can not be empty');
@@ -463,8 +437,7 @@ RequestBase.prototype.field = function (name, value) {
 
   if (isObject(name)) {
     for (const key in name) {
-      if (Object.prototype.hasOwnProperty.call(name, key))
-        this.field(key, name[key]);
+      if (hasOwn(name, key)) this.field(key, name[key]);
     }
 
     return this;
@@ -472,8 +445,7 @@ RequestBase.prototype.field = function (name, value) {
 
   if (Array.isArray(value)) {
     for (const i in value) {
-      if (Object.prototype.hasOwnProperty.call(value, i))
-        this.field(name, value[i]);
+      if (hasOwn(value, i)) this.field(name, value[i]);
     }
 
     return this;
@@ -488,7 +460,7 @@ RequestBase.prototype.field = function (name, value) {
     value = String(value);
   }
 
-  this._getFormData().append(name, value);
+  this._getFormData().append(name, value, options);
   return this;
 };
 
@@ -505,7 +477,36 @@ RequestBase.prototype.abort = function () {
 
   this._aborted = true;
   if (this.xhr) this.xhr.abort(); // browser
-  if (this.req) this.req.abort(); // node
+  if (this.req) {
+    // Node v13 has major differences in `abort()`
+    // https://github.com/nodejs/node/blob/v12.x/lib/internal/streams/end-of-stream.js
+    // https://github.com/nodejs/node/blob/v13.x/lib/internal/streams/end-of-stream.js
+    // https://github.com/nodejs/node/blob/v14.x/lib/internal/streams/end-of-stream.js
+    // (if you run a diff across these you will see the differences)
+    //
+    // References:
+    // <https://github.com/nodejs/node/issues/31630>
+    // <https://github.com/visionmedia/superagent/pull/1084/commits/dc18679a7c5ccfc6046d882015e5126888973bc8>
+    //
+    // Thanks to @shadowgate15 and @niftylettuce
+    if (
+      semver.gte(process.version, 'v13.0.0') &&
+      semver.lt(process.version, 'v14.0.0')
+    ) {
+      // Note that the reason this doesn't work is because in v13 as compared to v14
+      // there is no `callback = nop` set in end-of-stream.js above
+      throw new Error(
+        'Superagent does not work in v13 properly with abort() due to Node.js core changes'
+      );
+    } else if (semver.gte(process.version, 'v14.0.0')) {
+      // We have to manually set `destroyed` to `true` in order for this to work
+      // (see core internals of end-of-stream.js above in v14 branch as compared to v12)
+      this.req.destroyed = true;
+    }
+
+    this.req.abort(); // node
+  }
+
   this.clearTimeout();
   this.emit('abort');
   return this;
@@ -661,8 +662,7 @@ RequestBase.prototype.send = function (data) {
   // merge
   if (isObject_ && isObject(this._data)) {
     for (const key in data) {
-      if (Object.prototype.hasOwnProperty.call(data, key))
-        this._data[key] = data[key];
+      if (hasOwn(data, key)) this._data[key] = data[key];
     }
   } else if (typeof data === 'string') {
     // default to x-www-form-urlencoded
@@ -765,14 +765,14 @@ RequestBase.prototype._timeoutError = function (reason, timeout, errno) {
     return;
   }
 
-  const err = new Error(`${reason + timeout}ms exceeded`);
-  err.timeout = timeout;
-  err.code = 'ECONNABORTED';
-  err.errno = errno;
+  const error = new Error(`${reason + timeout}ms exceeded`);
+  error.timeout = timeout;
+  error.code = 'ECONNABORTED';
+  error.errno = errno;
   this.timedout = true;
-  this.timedoutError = err;
+  this.timedoutError = error;
   this.abort();
-  this.callback(err);
+  this.callback(error);
 };
 
 RequestBase.prototype._setTimeouts = function () {
