@@ -1,11 +1,18 @@
-const setup = require('./support/setup');
-
-const { uri } = setup;
 const assert = require('assert');
+const getSetup = require('./support/setup');
+
 const request = require('./support/client');
 
 describe('request', function () {
-  this.timeout(20000);
+  let setup;
+  let uri;
+
+  before(async () => {
+    setup = await getSetup();
+    uri = setup.uri;
+  });
+
+  this.timeout(20_000);
 
   it('Request inheritance', () => {
     assert(request.get(`${uri}/`) instanceof request.Request);
@@ -17,181 +24,181 @@ describe('request', function () {
   });
 
   it('request() simple GET', (next) => {
-    request('GET', `${uri}/ok`).end((err, res) => {
+    request('GET', `${uri}/ok`).end((error, res) => {
       try {
         assert(res instanceof request.Response, 'respond with Response');
         assert(res.ok, 'response should be ok');
         assert(res.text, 'res.text');
         next();
-      } catch (err_) {
-        next(err_);
+      } catch (err) {
+        next(err);
       }
     });
   });
 
   it('request() simple HEAD', (next) => {
-    request.head(`${uri}/ok`).end((err, res) => {
+    request.head(`${uri}/ok`).end((error, res) => {
       try {
         assert(res instanceof request.Response, 'respond with Response');
         assert(res.ok, 'response should be ok');
         assert(!res.text, 'res.text');
         next();
-      } catch (err_) {
-        next(err_);
+      } catch (err) {
+        next(err);
       }
     });
   });
 
   it('request() GET 5xx', (next) => {
-    request('GET', `${uri}/error`).end((err, res) => {
+    request('GET', `${uri}/error`).end((error, res) => {
       try {
-        assert(err);
-        assert.equal(err.message, 'Internal Server Error');
+        assert(error);
+        assert.equal(error.message, 'Internal Server Error');
         assert(!res.ok, 'response should not be ok');
         assert(res.error, 'response should be an error');
         assert(!res.clientError, 'response should not be a client error');
         assert(res.serverError, 'response should be a server error');
         next();
-      } catch (err_) {
-        next(err_);
+      } catch (err) {
+        next(err);
       }
     });
   });
 
   it('request() GET 4xx', (next) => {
-    request('GET', `${uri}/notfound`).end((err, res) => {
+    request('GET', `${uri}/notfound`).end((error, res) => {
       try {
-        assert(err);
-        assert.equal(err.message, 'Not Found');
+        assert(error);
+        assert.equal(error.message, 'Not Found');
         assert(!res.ok, 'response should not be ok');
         assert(res.error, 'response should be an error');
         assert(res.clientError, 'response should be a client error');
         assert(!res.serverError, 'response should not be a server error');
         next();
-      } catch (err_) {
-        next(err_);
+      } catch (err) {
+        next(err);
       }
     });
   });
 
   it('request() GET 404 Not Found', (next) => {
-    request('GET', `${uri}/notfound`).end((err, res) => {
+    request('GET', `${uri}/notfound`).end((error, res) => {
       try {
-        assert(err);
+        assert(error);
         assert(res.notFound, 'response should be .notFound');
         next();
-      } catch (err_) {
-        next(err_);
+      } catch (err) {
+        next(err);
       }
     });
   });
 
   it('request() GET 400 Bad Request', (next) => {
-    request('GET', `${uri}/bad-request`).end((err, res) => {
+    request('GET', `${uri}/bad-request`).end((error, res) => {
       try {
-        assert(err);
+        assert(error);
         assert(res.badRequest, 'response should be .badRequest');
         next();
-      } catch (err_) {
-        next(err_);
+      } catch (err) {
+        next(err);
       }
     });
   });
 
   it('request() GET 401 Bad Request', (next) => {
-    request('GET', `${uri}/unauthorized`).end((err, res) => {
+    request('GET', `${uri}/unauthorized`).end((error, res) => {
       try {
-        assert(err);
+        assert(error);
         assert(res.unauthorized, 'response should be .unauthorized');
         next();
-      } catch (err_) {
-        next(err_);
+      } catch (err) {
+        next(err);
       }
     });
   });
 
   it('request() GET 406 Not Acceptable', (next) => {
-    request('GET', `${uri}/not-acceptable`).end((err, res) => {
+    request('GET', `${uri}/not-acceptable`).end((error, res) => {
       try {
-        assert(err);
+        assert(error);
         assert(res.notAcceptable, 'response should be .notAcceptable');
         next();
-      } catch (err_) {
-        next(err_);
+      } catch (err) {
+        next(err);
       }
     });
   });
 
   it('request() GET 204 No Content', (next) => {
-    request('GET', `${uri}/no-content`).end((err, res) => {
+    request('GET', `${uri}/no-content`).end((error, res) => {
       try {
-        assert.ifError(err);
+        assert.ifError(error);
         assert(res.noContent, 'response should be .noContent');
         next();
-      } catch (err_) {
-        next(err_);
+      } catch (err) {
+        next(err);
       }
     });
   });
 
   it('request() DELETE 204 No Content', (next) => {
-    request('DELETE', `${uri}/no-content`).end((err, res) => {
+    request('DELETE', `${uri}/no-content`).end((error, res) => {
       try {
-        assert.ifError(err);
+        assert.ifError(error);
         assert(res.noContent, 'response should be .noContent');
         next();
-      } catch (err_) {
-        next(err_);
+      } catch (err) {
+        next(err);
       }
     });
   });
 
   it('request() header parsing', (next) => {
-    request('GET', `${uri}/notfound`).end((err, res) => {
+    request('GET', `${uri}/notfound`).end((error, res) => {
       try {
-        assert(err);
+        assert(error);
         assert.equal('text/html; charset=utf-8', res.header['content-type']);
         assert.equal('Express', res.header['x-powered-by']);
         next();
-      } catch (err_) {
-        next(err_);
+      } catch (err) {
+        next(err);
       }
     });
   });
 
   it('request() .status', (next) => {
-    request('GET', `${uri}/notfound`).end((err, res) => {
+    request('GET', `${uri}/notfound`).end((error, res) => {
       try {
-        assert(err);
+        assert(error);
         assert.equal(404, res.status, 'response .status');
         assert.equal(4, res.statusType, 'response .statusType');
         next();
-      } catch (err_) {
-        next(err_);
+      } catch (err) {
+        next(err);
       }
     });
   });
 
   it('get()', (next) => {
-    request.get(`${uri}/notfound`).end((err, res) => {
+    request.get(`${uri}/notfound`).end((error, res) => {
       try {
-        assert(err);
+        assert(error);
         assert.equal(404, res.status, 'response .status');
         assert.equal(4, res.statusType, 'response .statusType');
         next();
-      } catch (err_) {
-        next(err_);
+      } catch (err) {
+        next(err);
       }
     });
   });
 
   it('put()', (next) => {
-    request.put(`${uri}/user/12`).end((err, res) => {
+    request.put(`${uri}/user/12`).end((error, res) => {
       try {
         assert.equal('updated', res.text, 'response text');
         next();
-      } catch (err_) {
-        next(err_);
+      } catch (err) {
+        next(err);
       }
     });
   });
@@ -200,45 +207,45 @@ describe('request', function () {
     request
       .put(`${uri}/user/13/body`)
       .send({ user: 'new' })
-      .end((err, res) => {
+      .end((error, res) => {
         try {
           assert.equal('received new', res.text, 'response text');
           next();
-        } catch (err_) {
-          next(err_);
+        } catch (err) {
+          next(err);
         }
       });
   });
 
   it('post()', (next) => {
-    request.post(`${uri}/user`).end((err, res) => {
+    request.post(`${uri}/user`).end((error, res) => {
       try {
         assert.equal('created', res.text, 'response text');
         next();
-      } catch (err_) {
-        next(err_);
+      } catch (err) {
+        next(err);
       }
     });
   });
 
   it('del()', (next) => {
-    request.del(`${uri}/user/12`).end((err, res) => {
+    request.del(`${uri}/user/12`).end((error, res) => {
       try {
         assert.equal('deleted', res.text, 'response text');
         next();
-      } catch (err_) {
-        next(err_);
+      } catch (err) {
+        next(err);
       }
     });
   });
 
   it('delete()', (next) => {
-    request.delete(`${uri}/user/12`).end((err, res) => {
+    request.delete(`${uri}/user/12`).end((error, res) => {
       try {
         assert.equal('deleted', res.text, 'response text');
         next();
-      } catch (err_) {
-        next(err_);
+      } catch (err) {
+        next(err);
       }
     });
   });
@@ -248,12 +255,12 @@ describe('request', function () {
       .post(`${uri}/todo/item`)
       .type('application/octet-stream')
       .send('tobi')
-      .end((err, res) => {
+      .end((error, res) => {
         try {
           assert.equal('added "tobi"', res.text, 'response text');
           next();
-        } catch (err_) {
-          next(err_);
+        } catch (err) {
+          next(err);
         }
       });
   });
@@ -263,12 +270,12 @@ describe('request', function () {
       .post(`${uri}/user/12/pet`)
       .type('urlencoded')
       .send('pet=tobi')
-      .end((err, res) => {
+      .end((error, res) => {
         try {
           assert.equal('added pet "tobi"', res.text, 'response text');
           next();
-        } catch (err_) {
-          next(err_);
+        } catch (err) {
+          next(err);
         }
       });
   });
@@ -278,12 +285,12 @@ describe('request', function () {
       .post(`${uri}/user/12/pet`)
       .type('application/x-www-form-urlencoded')
       .send('pet=tobi')
-      .end((err, res) => {
+      .end((error, res) => {
         try {
           assert.equal('added pet "tobi"', res.text, 'response text');
           next();
-        } catch (err_) {
-          next(err_);
+        } catch (err) {
+          next(err);
         }
       });
   });
@@ -302,12 +309,12 @@ describe('request', function () {
     request
       .get(`${uri}/echo-header/accept`)
       .set('Accept', 'foo/bar')
-      .end((err, res) => {
+      .end((error, res) => {
         try {
           assert.equal('foo/bar', res.text);
           next();
-        } catch (err_) {
-          next(err_);
+        } catch (err) {
+          next(err);
         }
       });
   });
@@ -316,12 +323,12 @@ describe('request', function () {
     request
       .get(`${uri}/echo-header/accept`)
       .accept('json')
-      .end((err, res) => {
+      .end((error, res) => {
         try {
           assert.equal('application/json', res.text);
           next();
-        } catch (err_) {
-          next(err_);
+        } catch (err) {
+          next(err);
         }
       });
   });
@@ -330,12 +337,12 @@ describe('request', function () {
     request
       .get(`${uri}/echo-header/accept`)
       .accept('application/json')
-      .end((err, res) => {
+      .end((error, res) => {
         try {
           assert.equal('application/json', res.text);
           next();
-        } catch (err_) {
-          next(err_);
+        } catch (err) {
+          next(err);
         }
       });
   });
@@ -344,13 +351,13 @@ describe('request', function () {
     request
       .get(`${uri}/echo-header/accept`)
       .accept('xml')
-      .end((err, res) => {
+      .end((error, res) => {
         try {
           // We can't depend on mime module to be consistent with this
           assert(res.text == 'application/xml' || res.text == 'text/xml');
           next();
-        } catch (err_) {
-          next(err_);
+        } catch (err) {
+          next(err);
         }
       });
   });
@@ -359,12 +366,12 @@ describe('request', function () {
     request
       .get(`${uri}/echo-header/accept`)
       .accept('application/xml')
-      .end((err, res) => {
+      .end((error, res) => {
         try {
           assert.equal('application/xml', res.text);
           next();
-        } catch (err_) {
-          next(err_);
+        } catch (err) {
+          next(err);
         }
       });
   });
@@ -376,12 +383,12 @@ describe('request', function () {
       .put(`${uri}/echo-header/content-type`)
       .set('Content-Type', 'text/plain')
       .send('wahoo')
-      .end((err, res) => {
+      .end((error, res) => {
         try {
           assert.equal('text/plain', res.text);
           next();
-        } catch (err_) {
-          next(err_);
+        } catch (err) {
+          next(err);
         }
       });
   });
@@ -391,12 +398,12 @@ describe('request', function () {
       .put(`${uri}/echo-header/content-type`)
       .set('Content-Type', 'text/plain')
       .send('wahoo')
-      .end((err, res) => {
+      .end((error, res) => {
         try {
           assert.equal('text/plain', res.text);
           next();
-        } catch (err_) {
-          next(err_);
+        } catch (err) {
+          next(err);
         }
       });
   });
@@ -406,12 +413,12 @@ describe('request', function () {
       .put(`${uri}/echo-header/content-type`)
       .set('Content-Type', 'text/plain')
       .send('wahoo')
-      .end((err, res) => {
+      .end((error, res) => {
         try {
           assert.equal('text/plain', res.text);
           next();
-        } catch (err_) {
-          next(err_);
+        } catch (err) {
+          next(err);
         }
       });
   });
@@ -421,12 +428,12 @@ describe('request', function () {
       .put(`${uri}/echo-header/content-type`)
       .set({ 'Content-Type': 'text/plain' })
       .send('wahoo')
-      .end((err, res) => {
+      .end((error, res) => {
         try {
           assert.equal('text/plain', res.text);
           next();
-        } catch (err_) {
-          next(err_);
+        } catch (err) {
+          next(err);
         }
       });
   });
@@ -436,12 +443,12 @@ describe('request', function () {
       .post(`${uri}/pet`)
       .type('urlencoded')
       .send({ name: 'Manny', species: 'cat' })
-      .end((err, res) => {
+      .end((error, res) => {
         try {
           assert.equal('added Manny the cat', res.text);
           next();
-        } catch (err_) {
-          next(err_);
+        } catch (err) {
+          next(err);
         }
       });
   });
@@ -451,12 +458,12 @@ describe('request', function () {
       .post(`${uri}/pet`)
       .type('json')
       .send({ name: 'Manny', species: 'cat' })
-      .end((err, res) => {
+      .end((error, res) => {
         try {
           assert.equal('added Manny the cat', res.text);
           next();
-        } catch (err_) {
-          next(err_);
+        } catch (err) {
+          next(err);
         }
       });
   });
@@ -465,7 +472,7 @@ describe('request', function () {
     request
       .post(`${uri}/echo`)
       .send([1, 2, 3])
-      .end((err, res) => {
+      .end((error, res) => {
         try {
           assert.equal(
             'application/json',
@@ -473,8 +480,8 @@ describe('request', function () {
           );
           assert.equal('[1,2,3]', res.text);
           next();
-        } catch (err_) {
-          next(err_);
+        } catch (err) {
+          next(err);
         }
       });
   });
@@ -483,12 +490,12 @@ describe('request', function () {
     request
       .post(`${uri}/pet`)
       .send({ name: 'Manny', species: 'cat' })
-      .end((err, res) => {
+      .end((error, res) => {
         try {
           assert.equal('added Manny the cat', res.text);
           next();
-        } catch (err_) {
-          next(err_);
+        } catch (err) {
+          next(err);
         }
       });
   });
@@ -498,12 +505,12 @@ describe('request', function () {
       .post(`${uri}/echo`)
       .set('Content-Type', 'application/json; charset=UTF-8')
       .send({ data: ['data1', 'data2'] })
-      .end((err, res) => {
+      .end((error, res) => {
         try {
           assert.equal('{"data":["data1","data2"]}', res.text);
           next();
-        } catch (err_) {
-          next(err_);
+        } catch (err) {
+          next(err);
         }
       });
   });
@@ -513,12 +520,12 @@ describe('request', function () {
       .post(`${uri}/echo`)
       .set('Content-Type', 'application/vnd.example+json')
       .send({ data: ['data1', 'data2'] })
-      .end((err, res) => {
+      .end((error, res) => {
         try {
           assert.equal('{"data":["data1","data2"]}', res.text);
           next();
-        } catch (err_) {
-          next(err_);
+        } catch (err) {
+          next(err);
         }
       });
   });
@@ -528,12 +535,12 @@ describe('request', function () {
       .post(`${uri}/pet`)
       .send({ name: 'Manny' })
       .send({ species: 'cat' })
-      .end((err, res) => {
+      .end((error, res) => {
         try {
           assert.equal('added Manny the cat', res.text);
           next();
-        } catch (err_) {
-          next(err_);
+        } catch (err) {
+          next(err);
         }
       });
   });
@@ -543,7 +550,7 @@ describe('request', function () {
       .post(`${uri}/echo`)
       .send('user[name]=tj')
       .send('user[email]=tj@vision-media.ca')
-      .end((err, res) => {
+      .end((error, res) => {
         try {
           assert.equal(
             'application/x-www-form-urlencoded',
@@ -554,8 +561,8 @@ describe('request', function () {
             'user[name]=tj&user[email]=tj@vision-media.ca'
           );
           next();
-        } catch (err_) {
-          next(err_);
+        } catch (err) {
+          next(err);
         }
       });
   });
@@ -564,46 +571,46 @@ describe('request', function () {
     request
       .post(`${uri}/empty-body`)
       .send()
-      .end((err, res) => {
+      .end((error, res) => {
         try {
-          assert.ifError(err);
+          assert.ifError(error);
           assert(res.noContent, 'response should be .noContent');
           next();
-        } catch (err_) {
-          next(err_);
+        } catch (err) {
+          next(err);
         }
       });
   });
 
   it('GET .type', (next) => {
-    request.get(`${uri}/pets`).end((err, res) => {
+    request.get(`${uri}/pets`).end((error, res) => {
       try {
         assert.equal('application/json', res.type);
         next();
-      } catch (err_) {
-        next(err_);
+      } catch (err) {
+        next(err);
       }
     });
   });
 
   it('GET Content-Type params', (next) => {
-    request.get(`${uri}/text`).end((err, res) => {
+    request.get(`${uri}/text`).end((error, res) => {
       try {
         assert.equal('utf-8', res.charset);
         next();
-      } catch (err_) {
-        next(err_);
+      } catch (err) {
+        next(err);
       }
     });
   });
 
   it('GET json', (next) => {
-    request.get(`${uri}/pets`).end((err, res) => {
+    request.get(`${uri}/pets`).end((error, res) => {
       try {
         assert.deepEqual(res.body, ['tobi', 'loki', 'jane']);
         next();
-      } catch (err_) {
-        next(err_);
+      } catch (err) {
+        next(err);
       }
     });
   });
@@ -612,57 +619,57 @@ describe('request', function () {
     request
       .get(`${uri}/json-seq`)
       .buffer()
-      .end((err, res) => {
+      .end((error, res) => {
         try {
-          assert.ifError(err);
+          assert.ifError(error);
           assert.deepEqual(res.text, '\u001E{"id":1}\n\u001E{"id":2}\n');
           next();
-        } catch (err_) {
-          next(err_);
+        } catch (err) {
+          next(err);
         }
       });
   });
 
   it('GET x-www-form-urlencoded', (next) => {
-    request.get(`${uri}/foo`).end((err, res) => {
+    request.get(`${uri}/foo`).end((error, res) => {
       try {
         assert.deepEqual(res.body, { foo: 'bar' });
         next();
-      } catch (err_) {
-        next(err_);
+      } catch (err) {
+        next(err);
       }
     });
   });
 
   it('GET shorthand', (next) => {
-    request.get(`${uri}/foo`, (err, res) => {
+    request.get(`${uri}/foo`, (error, res) => {
       try {
         assert.equal('foo=bar', res.text);
         next();
-      } catch (err_) {
-        next(err_);
+      } catch (err) {
+        next(err);
       }
     });
   });
 
   it('POST shorthand', (next) => {
-    request.post(`${uri}/user/0/pet`, { pet: 'tobi' }, (err, res) => {
+    request.post(`${uri}/user/0/pet`, { pet: 'tobi' }, (error, res) => {
       try {
         assert.equal('added pet "tobi"', res.text);
         next();
-      } catch (err_) {
-        next(err_);
+      } catch (err) {
+        next(err);
       }
     });
   });
 
   it('POST shorthand without callback', (next) => {
-    request.post(`${uri}/user/0/pet`, { pet: 'tobi' }).end((err, res) => {
+    request.post(`${uri}/user/0/pet`, { pet: 'tobi' }).end((error, res) => {
       try {
         assert.equal('added pet "tobi"', res.text);
         next();
-      } catch (err_) {
-        next(err_);
+      } catch (err) {
+        next(err);
       }
     });
   });
@@ -671,12 +678,12 @@ describe('request', function () {
     request
       .get(`${uri}/querystring`)
       .query({ val: ['a', 'b', 'c'] })
-      .end((err, res) => {
+      .end((error, res) => {
         try {
           assert.deepEqual(res.body, { val: ['a', 'b', 'c'] });
           next();
-        } catch (err_) {
-          next(err_);
+        } catch (err) {
+          next(err);
         }
       });
   });
@@ -685,7 +692,7 @@ describe('request', function () {
     request
       .get(`${uri}/querystring`)
       .query({ array: ['a', 'b', 'c'], string: 'foo', number: 10 })
-      .end((err, res) => {
+      .end((error, res) => {
         try {
           assert.deepEqual(res.body, {
             array: ['a', 'b', 'c'],
@@ -693,8 +700,8 @@ describe('request', function () {
             number: 10
           });
           next();
-        } catch (err_) {
-          next(err_);
+        } catch (err) {
+          next(err);
         }
       });
   });
@@ -703,15 +710,15 @@ describe('request', function () {
     request
       .get(`${uri}/querystring`)
       .query({ array1: ['a', 'b', 'c'], array2: [1, 2, 3] })
-      .end((err, res) => {
+      .end((error, res) => {
         try {
           assert.deepEqual(res.body, {
             array1: ['a', 'b', 'c'],
             array2: [1, 2, 3]
           });
           next();
-        } catch (err_) {
-          next(err_);
+        } catch (err) {
+          next(err);
         }
       });
   });
@@ -720,12 +727,12 @@ describe('request', function () {
     request
       .get(`${uri}/querystring`)
       .query({ search: 'Manny' })
-      .end((err, res) => {
+      .end((error, res) => {
         try {
           assert.deepEqual(res.body, { search: 'Manny' });
           next();
-        } catch (err_) {
-          next(err_);
+        } catch (err) {
+          next(err);
         }
       });
   });
@@ -734,12 +741,12 @@ describe('request', function () {
     request
       .get(`${uri}/querystring?search=Manny`)
       .query({ range: '1..5' })
-      .end((err, res) => {
+      .end((error, res) => {
         try {
           assert.deepEqual(res.body, { search: 'Manny', range: '1..5' });
           next();
-        } catch (err_) {
-          next(err_);
+        } catch (err) {
+          next(err);
         }
       });
   });
@@ -750,7 +757,7 @@ describe('request', function () {
       .query({ search: 'Manny' })
       .query({ range: '1..5' })
       .query({ order: 'desc' })
-      .end((err, res) => {
+      .end((error, res) => {
         try {
           assert.deepEqual(res.body, {
             search: 'Manny',
@@ -758,8 +765,8 @@ describe('request', function () {
             order: 'desc'
           });
           next();
-        } catch (err_) {
-          next(err_);
+        } catch (err) {
+          next(err);
         }
       });
   });
@@ -770,7 +777,7 @@ describe('request', function () {
       .query('search=Manny')
       .query('range=1..5')
       .query('order=desc')
-      .end((err, res) => {
+      .end((error, res) => {
         try {
           assert.deepEqual(res.body, {
             search: 'Manny',
@@ -778,8 +785,8 @@ describe('request', function () {
             order: 'desc'
           });
           next();
-        } catch (err_) {
-          next(err_);
+        } catch (err) {
+          next(err);
         }
       });
   });
@@ -789,7 +796,7 @@ describe('request', function () {
       .get(`${uri}/querystring`)
       .query('search=Manny')
       .query({ order: 'desc', range: '1..5' })
-      .end((err, res) => {
+      .end((error, res) => {
         try {
           assert.deepEqual(res.body, {
             search: 'Manny',
@@ -797,8 +804,8 @@ describe('request', function () {
             order: 'desc'
           });
           next();
-        } catch (err_) {
-          next(err_);
+        } catch (err) {
+          next(err);
         }
       });
   });
@@ -807,12 +814,12 @@ describe('request', function () {
     request.get(
       `${uri}/querystring`,
       { foo: 'FOO', bar: 'BAR' },
-      (err, res) => {
+      (error, res) => {
         try {
           assert.deepEqual(res.body, { foo: 'FOO', bar: 'BAR' });
           next();
-        } catch (err_) {
-          next(err_);
+        } catch (err) {
+          next(err);
         }
       }
     );
@@ -822,89 +829,89 @@ describe('request', function () {
     request.head(
       `${uri}/querystring-in-header`,
       { foo: 'FOO', bar: 'BAR' },
-      (err, res) => {
+      (error, res) => {
         try {
           assert.deepEqual(JSON.parse(res.headers.query), {
             foo: 'FOO',
             bar: 'BAR'
           });
           next();
-        } catch (err_) {
-          next(err_);
+        } catch (err) {
+          next(err);
         }
       }
     );
   });
 
   it('request(method, url)', (next) => {
-    request('GET', `${uri}/foo`).end((err, res) => {
+    request('GET', `${uri}/foo`).end((error, res) => {
       try {
         assert.equal('bar', res.body.foo);
         next();
-      } catch (err_) {
-        next(err_);
+      } catch (err) {
+        next(err);
       }
     });
   });
 
   it('request(url)', (next) => {
-    request(`${uri}/foo`).end((err, res) => {
+    request(`${uri}/foo`).end((error, res) => {
       try {
         assert.equal('bar', res.body.foo);
         next();
-      } catch (err_) {
-        next(err_);
+      } catch (err) {
+        next(err);
       }
     });
   });
 
   it('request(url, fn)', (next) => {
-    request(`${uri}/foo`, (err, res) => {
+    request(`${uri}/foo`, (error, res) => {
       try {
         assert.equal('bar', res.body.foo);
         next();
-      } catch (err_) {
-        next(err_);
+      } catch (err) {
+        next(err);
       }
     });
   });
 
   it('req.timeout(ms)', (next) => {
-    const req = request.get(`${uri}/delay/3000`).timeout(1000);
-    req.end((err, res) => {
+    const request_ = request.get(`${uri}/delay/3000`).timeout(1000);
+    request_.end((error, res) => {
       try {
-        assert(err, 'error missing');
-        assert.equal(1000, err.timeout, 'err.timeout missing');
+        assert(error, 'error missing');
+        assert.equal(1000, error.timeout, 'err.timeout missing');
         assert.equal(
           'Timeout of 1000ms exceeded',
-          err.message,
+          error.message,
           'err.message incorrect'
         );
         assert.equal(null, res);
-        assert(req.timedout, true);
+        assert(request_.timedout, true);
         next();
-      } catch (err_) {
-        next(err_);
+      } catch (err) {
+        next(err);
       }
     });
   });
 
   it('req.timeout(ms) with redirect', (next) => {
-    const req = request.get(`${uri}/delay/const`).timeout(1000);
-    req.end((err, res) => {
+    const request_ = request.get(`${uri}/delay/const`).timeout(1000);
+    request_.end((error, res) => {
       try {
-        assert(err, 'error missing');
-        assert.equal(1000, err.timeout, 'err.timeout missing');
+        assert(error, 'error missing');
+        assert.equal(1000, error.timeout, 'err.timeout missing');
         assert.equal(
           'Timeout of 1000ms exceeded',
-          err.message,
+          error.message,
           'err.message incorrect'
         );
         assert.equal(null, res);
-        assert(req.timedout, true);
+        assert(request_.timedout, true);
         next();
-      } catch (err_) {
-        next(err_);
+      } catch (err) {
+        next(err);
       }
     });
   });
@@ -912,9 +919,9 @@ describe('request', function () {
   it('request event', (next) => {
     request
       .get(`${uri}/foo`)
-      .on('request', (req) => {
+      .on('request', (request_) => {
         try {
-          assert.equal(`${uri}/foo`, req.url);
+          assert.equal(`${uri}/foo`, request_.url);
           next();
         } catch (err) {
           next(err);
@@ -938,26 +945,27 @@ describe('request', function () {
   });
 
   it('response should set statusCode', (next) => {
-    request.get(`${uri}/ok`, (err, res) => {
+    request.get(`${uri}/ok`, (error, res) => {
       try {
         assert.strictEqual(res.statusCode, 200);
         next();
-      } catch (err_) {
-        next(err_);
+      } catch (err) {
+        next(err);
       }
     });
   });
 
   it('req.toJSON()', (next) => {
-    request.get(`${uri}/ok`).end((err, res) => {
+    request.get(`${uri}/ok`).end((error, res) => {
       try {
         const j = (res.request || res.req).toJSON();
-        ['url', 'method', 'data', 'headers'].forEach((prop) => {
+        for (const prop of ['url', 'method', 'data', 'headers']) {
           assert(j.hasOwnProperty(prop));
-        });
+        }
+
         next();
-      } catch (err_) {
-        next(err_);
+      } catch (err) {
+        next(err);
       }
     });
   });
